DataTables example - Generated content for a column

# DataTables example Generated content for a column

In some tables you might wish to have some content generated automatically. This can be done in a number of ways:

- `columns.renderDT` for content that is dynamic (i.e. based upon the row's data)
- `columns.defaultContentDT` for static content (i.e. simple strings)

This examples shows the use of `columns.defaultContentDT` to create a button element in the last column of the table. A simple jQuery `click` event listener is used to watch for clicks on the row, and when activated uses the `row().data()DT` method to get the data for the row and show a bit of information about it in an `alert` box. This is a simple use case, but it can be built up to be arbitrarily complex.

Note also that the `columns.dataDT` option for the column has been set to `null` to indicate that the column has no information that should be obtained data source object.

Name | Position | Office | Extn. | Start date | Salary
--- | --- | --- | --- | --- | ---
Name | Position | Office | Extn. | Start date | Salary

- Javascript
- HTML
- CSS
- Ajax
- Server-side script

The Javascript shown below is used to initialise the table shown in this example:

`$(document).ready(function() { var table = $('#example').DataTable( { "ajax": "data/arrays.txt", "columnDefs": [ { "targets": -1, "data": null, "defaultContent": "<button>Click!</button>" } ] } ); $('#example tbody').on( 'click', 'button', function () { var data = table.row( $(this).parents('tr') ).data(); alert( data[0] +"'s salary is: "+ data[ 5 ] ); } ); } );`

In addition to the above code, the following Javascript library files are loaded for use in this example:

- ../../media/js/jquery.js
- ../../media/js/jquery.dataTables.js

The HTML shown below is the raw HTML table element, before it has been enhanced by DataTables:

This example uses a little bit of additional CSS beyond what is loaded from the library files (below), in order to correctly display the table. The additional CSS used is shown below:

``

The following CSS library files are loaded for use in this example to provide the styling of the table:

- ../../media/css/jquery.dataTables.css

This table loads data by Ajax. The latest data that has been loaded is shown below. This data will update automatically as any additional data is loaded.

The script used to perform the server-side processing for this table is shown below. Please note that this is just an example script using PHP. Server-side processing scripts can be written in any language, using the protocol described in the DataTables documentation.